@@ -1,4 +1,4 @@
-#!/usr/local/bin/tclsh8.5
+#!/usr/local/bin/tclsh8.6
 
 # Default dbus to monitor
 set bus session
@@ -28,7 +28,7 @@ array set type {
 }
 
 # Need at least version 2.0 of the Tcl dbus library
-package require dbus 2.0 3
+package require dbus 2.0 3 4
 
 # Assign signature elements to variables, similar to lassign
 proc sigassign {sig args} {
@@ -234,12 +234,16 @@ if {$argc > 0} {
 	# Eavesdrop unless overridden by the user
 	set term [list -eavesdrop true]
 	foreach n [split $arg ,] { 
-	    if {[scan $n {%[a-z]=%s} option value] != 2} {
+	    if {[scan $n {%[a-z0-9_]=%n} option vpos] != 2} {
 		errormsg "invalid match rule"
-	    } elseif {$option ni {destination interface member path sender type eavesdrop}} {
-		errormsg "unknown key in match rule"
+	    } elseif {$option ni {destination interface member path sender \
+	      type eavesdrop arg0namespace}} {
+		set num [scan $option {arg%[0-9]%npath%n} arg pos pos]
+		if {$num < 2 || $pos < [string length $option]} {
+		    errormsg "unknown key in match rule"
+		}
 	    }
-	    lappend term -$option $value
+	    lappend term -$option [string range $n $vpos end]
 	}
 	lappend filter $term
     }
